@@ -1,6 +1,6 @@
 /*
  *  ScanGear MP for Linux
- *  Copyright CANON INC. 2007-2017
+ *  Copyright CANON INC. 2007-2021
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -298,7 +298,7 @@ static int ui_dialog_save_scan_start( SGMP_Data *data, LPCNMS_ROOT root )
 	int					i;
 	int					ret = -1;
 	int					status;
-	char				*buf;
+	char				*buf = NULL;
 	int					errCode;
 	int					readBytes = 0;
 	int					result = CIJSC_SCANMAIN_SCAN_FINISHED;
