@@ -3,7 +3,7 @@
 ##############################################################################
 ##
 ##  ScanGear MP for Linux
-##  Copyright CANON INC. 2007-2017
+##  Copyright CANON INC. 2007-2021
 ##
 ##  This program is free software; you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
 ##
 ##############################################################################
 
-C_version="3.50-1"
-C_copyright_end="2017"
+C_version="4.30-1"
+C_copyright_end="2021"
 C_default_system="rpm"
 
 L_INST_COM_01_01="Command executed = %s\n"
@@ -29,7 +29,7 @@ L_INST_COM_01_01="Command executed = %s\n"
 L_INST_COM_01_02="An error occurred. The package management system cannot be identified.\n"
 L_INST_COM_01_03="An error occurred. A necessary package could not be found in the proper location.\n"
 L_INST_COM_01_04="Installation has been completed.\n"
-L_INST_COM_01_05="An error occurred. Your environment cannot be identified as 32-bit or 64-bit.\nTry to install again by using the following command.\n"
+L_INST_COM_01_05="An error occurred. Your environment cannot be identified.\nTry to install again by using the following command.\n"
 L_INST_COM_01_06="An error occurred. The specified environment differs from your environment.\nTry to install again by using the following command.\n"
 
 L_INST_COM_02_01="Usage: %s\n"
